@@ -24,11 +24,9 @@ class BreitBartIE(InfoExtractor):
         webpage = self._download_webpage(url, video_id)
 
         formats = self._extract_m3u8_formats(f'https://cdn.jwplayer.com/manifests/{video_id}.m3u8', video_id, ext='mp4')
-        self._sort_formats(formats)
         return {
             'id': video_id,
-            'title': (self._og_search_title(webpage, default=None)
-                      or self._html_extract_title(webpage, 'video title')),
+            'title': self._generic_title('', webpage),
             'description': self._og_search_description(webpage),
             'thumbnail': self._og_search_thumbnail(webpage),
             'age_limit': self._rta_search(webpage),
